/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __TAC_COMMON_H__
#define __TAC_COMMON_H__

#include <functional>

typedef enum {
	TAC_ERROR_NONE = 0,
	TAC_ERROR_INVALID_PARAMETER = -1,
	TAC_ERROR_ALREADY_EXIST = -2,
	TAC_ERROR_NO_SUCH_FILE = -3,
	TAC_ERROR_INVALID_PACKAGE = -4,
	TAC_ERROR_NOT_SUPPORTED = -5,
	TAC_ERROR_UNKNOWN = -9
} tac_error_e;

/**
 * @brief restore database of TAC
 * @return tac_error_e
 */
tac_error_e restoreTACDB();

/**
 * @brief remove a symbolic link file, the native images of TAC for specific package.
 * @param[i] pkgId package ID
 * @return tac_error_e
 */
tac_error_e resetTACPackage(const std::string& pkgId);

/**
 * @brief creates a symbolic link file, the native image of TAC for specific package.
 * @param[i] pkgId package ID
 * @return tac_error_e
 */
tac_error_e createTACPackage(const std::string& pkgId, DWORD flags);

/**
 * @brief regenerate native image of TAC for all shared assembly.
 * @return tac_error_e
 */
tac_error_e regenerateTAC(DWORD flags);

/**
 * @brief disable tac feature.
 * @param[i] pkgId package ID
 * @return tac_error_e
 */
tac_error_e disableTACPackage(const std::string& pkgId);

/**
 * @brief enable tac feature.
 * @param[i] pkgId package ID
 * @return tac_error_e
 */
tac_error_e enableTACPackage(const std::string& pkgId);

#endif /* __TAC_COMMON_H__ */
